#
# spec file for package speech-dispatcher
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1500
%define espeak    espeak-ng
%define espeakdev espeak-ng-devel
%else
%define espeak    espeak
%define espeakdev espeak-devel
%endif

Name:           speech-dispatcher
Version:        0.8.8
Release:        lp150.64.4
# FIXME missing backends: festival lite, ibmeci (ibm tts), dumbtts/ivona, nas
# Almost all files are under GPLv2+, however src/c/clients/spdsend/spdsend.h is
# licensed under GPLv2, which makes %%{_bindir}/spdsend GPLv2.
Summary:        Device independent layer for speech synthesis
License:        GPL-2.0-or-later
Group:          System/Daemons
URL:            https://devel.freebsoft.org/speechd
Source0:        https://devel.freebsoft.org/pub/projects/speechd/%{name}-%{version}.tar.gz
# Init file
Source1:        speech-dispatcherd.service
# Logrotate file taken from Debian
Source2:        speech-dispatcher.logrotate
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM bnc-831609-festival-crash.patch bnc#831609 mgorse@suse.com -- fix crash when unable to init festival module
BuildRequires:  %{espeakdev}
BuildRequires:  alsa-devel
BuildRequires:  dotconf-devel
BuildRequires:  glib2-devel
BuildRequires:  intltool
BuildRequires:  libao-devel
BuildRequires:  libpulse-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libtool
BuildRequires:  python3-setuptools
BuildRequires:  systemd
BuildRequires:  texinfo
Requires:       python3-speechd
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         %{install_info_prereq}
Recommends:     %{espeak}
Recommends:     speech-dispatcherd-module-espeak
Suggests:       festival
Suggests:       logrotate
Provides:       speechd = %{version}
Obsoletes:      speechd < %{version}
# In 12.1, with GNOME 3, gnome-speech is completely deprecated and
# speech-dispatcher replaces it. We don't have a Provides since this is
# really just about obsoleting at technology, not providing it.
Obsoletes:      gnome-speech <= 0.4.25
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
The goal of Speech Dispatcher project is to provide a high-level device
independent layer for speech synthesis through a simple, stable and
well documented interface.

What is a very high level GUI library to graphics, Speech Dispatcher is
to speech synthesis. The application neither needs to talk to the
devices directly nor to handle concurrent access, sound output and other
tricky aspects of the speech subsystem.

%package configure
Summary:        Configuration tool for Speech Dispatcher
Group:          System/Daemons
Requires:       %{name} = %{version}
Requires:       python3-xdg
Enhances:       %{name}

%description configure
The goal of Speech Dispatcher project is to provide a high-level device
independent layer for speech synthesis through a simple, stable and
well documented interface.

What is a very high level GUI library to graphics, Speech Dispatcher is
to speech synthesis. The application neither needs to talk to the
devices directly nor to handle concurrent access, sound output and other
tricky aspects of the speech subsystem.

This package contains spd-conf, a configuration tool for Speech
Dispatcher.

%package module-espeak
Summary:        ESpeak module for Speech Dispatcher
Group:          System/Daemons
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:%{espeak})

%description module-espeak
The goal of Speech Dispatcher project is to provide a high-level device
independent layer for speech synthesis through a simple, stable and
well documented interface.

What is a very high level GUI library to graphics, Speech Dispatcher is
to speech synthesis. The application neither needs to talk to the
devices directly nor to handle concurrent access, sound output and other
tricky aspects of the speech subsystem.

This package contains the espeak module.

%package -n libspeechd2
Summary:        Device independent layer for speech synthesis - Client library
Group:          System/Libraries
Recommends:     %{name}

%description -n libspeechd2
The goal of Speech Dispatcher project is to provide a high-level device
independent layer for speech synthesis through a simple, stable and
well documented interface.

What is a very high level GUI library to graphics, Speech Dispatcher is
to speech synthesis. The application neither needs to talk to the
devices directly nor to handle concurrent access, sound output and other
tricky aspects of the speech subsystem.

%package -n libspeechd-devel
Summary:        Device independent layer for speech synthesis - Development files
Group:          Development/Languages/C and C++
Requires:       libspeechd2 = %{version}
Provides:       %{name}-devel = %{version}
Provides:       speechd-devel = %{version}
Obsoletes:      speechd-devel < %{version}

%description -n libspeechd-devel
The goal of Speech Dispatcher project is to provide a high-level device
independent layer for speech synthesis through a simple, stable and
well documented interface.

What is a very high level GUI library to graphics, Speech Dispatcher is
to speech synthesis. The application neither needs to talk to the
devices directly nor to handle concurrent access, sound output and other
tricky aspects of the speech subsystem.

%package -n python3-speechd
Summary:        Device independent layer for speech synthesis - Python Bindings
Group:          Development/Libraries/Python
Requires:       %{name} >= %{version}

%description -n python3-speechd
The goal of Speech Dispatcher project is to provide a high-level device
independent layer for speech synthesis through a simple, stable and
well documented interface.

What is a very high level GUI library to graphics, Speech Dispatcher is
to speech synthesis. The application neither needs to talk to the
devices directly nor to handle concurrent access, sound output and other
tricky aspects of the speech subsystem.

%prep
%setup -q
# dummy module must almost never be dissabled
sed -i "s/#AddModule \"dummy\"/AddModule \"dummy\"/" -i config/speechd.conf
# you must enable at least one module (except dummy), otherwise it will load
# all available modules and may cause huge cpu usage!
sed -i "s/#AddModule \"%{espeak}\"/AddModule \"%{espeak}\"/" -i config/speechd.conf

%build
%configure --disable-static \
        --with-libao \
        --with-alsa \
        --with-pulse \
        --without-flite \
        --sysconfdir=%{_sysconfdir}
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print
# Install systemd service files
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcspeech-dispatcherd
# Create log dir. 0700 since the logs can contain user information.
install -d -m 0700 %{buildroot}%{_localstatedir}/log/speech-dispatcher/
# Install logrotate script
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/speech-dispatcher
# Remove config files for modules we don't support
rm %{buildroot}%{_sysconfdir}/speech-dispatcher/modules/flite.conf
rm %{buildroot}%{_sysconfdir}/speech-dispatcher/modules/ibmtts.conf
rm %{buildroot}%{_sysconfdir}/speech-dispatcher/modules/ivona.conf
# Remove config files that we don't need a second time
# but then user can not create its own configuration, because here is default, while in /etc is system-wide
# %{__rm} -r %{buildroot}%{_datadir}/speech-dispatcher/conf/
# Remove %{_infodir}/dir file
rm %{buildroot}%{_infodir}/dir
%find_lang %{name}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/spd-say.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/ssip.info.gz
%service_add_post speech-dispatcherd.service

%pre
%service_add_pre speech-dispatcherd.service

%preun
%service_del_preun speech-dispatcherd.service

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/spd-say.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/ssip.info.gz
%service_del_postun speech-dispatcherd.service

%post -n libspeechd2 -p /sbin/ldconfig

%postun -n libspeechd2 -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS ANNOUNCE NEWS README COPYING
%dir %{_sysconfdir}/speech-dispatcher/
%dir %{_sysconfdir}/speech-dispatcher/clients
%dir %{_sysconfdir}/speech-dispatcher/modules
%config(noreplace) %{_sysconfdir}/speech-dispatcher/speechd.conf
%config(noreplace) %{_sysconfdir}/speech-dispatcher/clients/*.conf
%config(noreplace) %{_sysconfdir}/speech-dispatcher/modules/*.conf
%exclude %{_sysconfdir}/speech-dispatcher/modules/espeak.conf
%{_bindir}/*
%exclude %{_bindir}/spd-conf
%{_datadir}/sounds/speech-dispatcher/
%dir %{_libdir}/speech-dispatcher
%{_libdir}/speech-dispatcher/spd_*.so
# When adding a module, also stop removing its config file in %install
%dir %{_libdir}/speech-dispatcher-modules
%{_libdir}/speech-dispatcher-modules/sd_cicero
%{_libdir}/speech-dispatcher-modules/sd_dummy
%{_libdir}/speech-dispatcher-modules/sd_festival
%{_libdir}/speech-dispatcher-modules/sd_generic
%doc %{_infodir}/%{name}*.info.gz
%doc %{_infodir}/spd-say.info.gz
%doc %{_infodir}/ssip.info.gz
# logs
%dir %attr(0700, root, root) %{_localstatedir}/log/speech-dispatcher/
%config(noreplace) %{_sysconfdir}/logrotate.d/speech-dispatcher
# systemd service file
%{_unitdir}/speech-dispatcherd.service
%{_sbindir}/rcspeech-dispatcherd

%files configure
%defattr(-,root,root,-)
%{_bindir}/spd-conf
%{python3_sitearch}/speechd_config/
%{_datadir}/speech-dispatcher/

%files module-espeak
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/speech-dispatcher/modules/espeak.conf
%{_libdir}/speech-dispatcher-modules/sd_%{espeak}

%files -n libspeechd2
%defattr(-,root,root,-)
%{_libdir}/libspeechd.so.*

%files -n libspeechd-devel
%defattr(-,root,root,-)
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n python3-speechd
%defattr(-,root,root,-)
%{python3_sitearch}/speechd/

%changelog
* Fri Aug  3 2018 mgorse@suse.com
- Fix enabling of espeak-ng  in speechd.conf to use
  espeak-ng.conf, rather than espeak.conf.
* Mon Mar  5 2018 aloisio@gmx.com
- Use espeak-ng when available
* Wed Feb  7 2018 aloisio@gmx.com
- Update to version 0.8.8
  * Add German translation, thanks to Chris Leick for the patch
  * Fix some spelling mistakes, thanks to Paul Gevers for the patch
  * Some slight code improvements
* Wed Jan  3 2018 dimstar@opensuse.org
- Add baselibs.conf: create libspeechd2-32bit, required by
  libQt5TextToSpeech5-32bit.
* Thu Nov 30 2017 dimstar@opensuse.org
- Drop py_requires: this is a static python2-dependency on a
  python3 package.
* Fri Sep 15 2017 mgorse@suse.com
- Update to version 0.8.7:
  + Further fixes to spd-conf, which should now work properly.
  + Split the espeak-ng driver code into its own source file.
  + Add a work-around to the espeak-ng driver to account for spaces
    in voice names which recently appeared in espeak-ng git master.
    This will properly be fixed in 0.9.
  + Voice names are not forced to lower case, due to espeak-ng
    git master now having multi-case voice names.
  + Fix stripped audio output from the flite module.
  + Further code and build improvements.
- Changes from version 0.8.6:
  + Various internal code improvements.
  + Fix more compiler warnings.
  + Python bug fixes with thanks to Sebastian Humenda.
- Changes from version 0.8.5:
  + Use GLib main loop for the main server thread
  + Implement a shutdown timer in the server
  + Add support for espeak-ng.
  + Document an ibmtts configuration option
  + Removal of configuration options in the code that were not
    actually being used.
  + Added a command-line argument to allow for custom modules
    location.
- Add ANNOUNCE; remove ChangeLog (no longer shipped)
* Sat Jul  1 2017 dimstar@opensuse.org
- Drop %%py_requires from python3-speechd: this is a python2
  dependency on a python3 package.
* Tue Oct  4 2016 ro@suse.de
- speech-dispatcher.logrotate: move options to local scope
  to not affect logrotate configuration for other services
  (bsc#1001618)
* Mon May 16 2016 mgorse@suse.com
- Update to version 0.8.4:
  + Updated documentation for required dependencies and where to
    find them.
  + Removed unused code.
  + Fixed compiler and GLib warnings.
  + Cleanup header definitions and inclusions.
  + Enabled silent rules by default
  + Fix language identification references.
* Sun Jul 19 2015 opensuse.lietuviu.kalba@gmail.com
- Update to version 0.8.3:
  * Add API methods to get language, rate, pitch, and volume.
  * A lot of code cleanup, and compatibility improvements.
  * Removed all references to GNOME Speech, since it has long since been
  deprecated.
  * Fix some inconsistancy in the SSIP API for voice type.
  * The SET VOICE SSIP command is now deprecated, and will be removed in 0.9.
  * The C library API now provides macro definitions for major, minor, and micro
  versions in libspeechd_versions.h.
  * The libsndfile library is now a mandetory dependency to improve the user
  experience around sound icons.
  * Fix a possible crash in the festival driver (drop bnc-831609-festival-crash.patch).
  * Add a configuration option to the espeak driver to show voice variants in the
  voice list. This will remain until a proper variants retrieval API is added
  for compatible synthesizers.
* Fri Mar 27 2015 benoit.monin@gmx.fr
- cleanup spec file with spec-cleaner
- update to version 0.8.2:
  * Add convenience methods to the libspeech API to free module
    list and voice data structures.
  * Add method to the libspeechd API to get the current output
    module, and update the documentation accordingly.
  * The API is now licensed under the GNU Lesser General Public
    License v2.1 or later.
  * The spdconf configuration utility is now translatable.
  * Fixed a bug where speech-dispatcher would fail to start if the
    user configuration directory existed but did not contain a
    config file.
  * Install the spdconf desktop file.
- add rcspeech-dispatcherd symlink for service
* Sat Dec 20 2014 opensuse.lietuviu.kalba@gmail.com
- Update to 0.8.1
  + User dictionaries support added to the IBMTTS driver
  + Added a pico configuration file for use with the generic driver
  + Better support for multi-arch enabled distros to facilitate the use of the
    i386 only IBMTTS driver being easily installable on an amd64 system
  + Bug fixes, and documentation cleanup
- Don't remove configuration in /usr/share/speech-dispatcher/config,
  because it is used by its configuration program to create user
  specific settings, while duplicate of it in /etc is system-wide
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Fri Sep 27 2013 mgorse@suse.com
- Add bnc-831609-festival-crash.patch -- fix crash when unable to init
  festival module.
* Mon Jun 17 2013 p.drouand@gmail.com
- Use systemd instead of sysvinit
- Remove %%clean section
* Sun May  5 2013 dimstar@opensuse.org
- Update to version 0.8:
  + No changes since 0.8beta1.
* Fri Apr 19 2013 dimstar@opensuse.org
- Update to 0.8beta1:
  + Python 3 compatibility of the Python bindings.
  + User configuration, logs and runtime files are now stored in
    directories according to the XDG specification.
  + Internationalization of spd-say and translations into
    Hungarian and Czech languages.
  + Espeak output can now use libsonic for faster speech.
  + Pico output module.
  + Lots of bugfixes, cleanups and fine-tunnings.
- Drop speech-dispatcher_paths+files.patch: fixed upstream.
- Replace python-setuptools with python3-setuptools.
- Add intltool and libtool BuildRequires: new dependencies.
- Rename python-speechd to python3-speechd, as the bindings are
  for python 3.
* Mon Jul 18 2011 vuntz@opensuse.org
- Add a gnome-speech Obsoletes: in GNOME 3, gnome-speech is
  deprecated and obsoleted by the use of speech-dispatcher.
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 0.7.1:
  + Easy configuration of the client communication method using a
    single environment variable SPEECHD_ADDRESS.
  + Advanced autospawn -- server is autostarted only when its
    communication channel matches the communication channels
    requested by the client. Local server is not started when
    client attempts to connect to a remote server.
  + Both libspeechd and python library now report a detailed error
    information in case of connection failure (why has connect
    failed, why was it not possible to autostart the server, what
    has the server reported etc.) Clients can directly show this
    information to the user and the user doesn't have to search
    them in logfiles.
  + Improvements in memory usage
  + Cleanup of priorities of messages in logging output
  + Various bugfixes, cleanups and fine-tunnings
- Changes from version 0.7:
  + Speech Dispatcher uses UNIX style sockets as default means of
    communication, thus avoiding the necessity to choose a numeric
    port and greatly easying session integration
  + Autospawn -- server is started automatically when a client
    requests it. It can be forbidden in the appropriate server
    configuration file
  + Pulse Audio output reworked and fixed
  + Dispatcher runs as user service (not system service) by default
    and doesn't require the previous presence of
    ~/.speech-dispatcher directory
  + All logging is now managed centrally, not by separate options
  + Graceful audio fallback (e.g. if pulse is not working, use
    Alsa...)
  + Audio output to different soundsystems through the libao
    library
  + Various bugfixes and fine-tunnings
  + Updated documentation
- Drop speech-dispatcher_python-makefile.patch,
  speech-dispatcher_extlink.patch, speech-dispatcher_getline.patch,
  speech-dispatcher_libspeechd.patch: fixed upstream.
- Update speech-dispatcher_paths+files.patch from Debian.
- Add libao-devel BuildRequires, and pass --with-libao to
  configure.
* Wed Apr  7 2010 vuntz@opensuse.org
- Completely rework the package, based on the Fedora and Debian
  packages.
- Rename the source package to speech-dispatcher, to follow
  upstream name.
* Sun Jan 31 2010 lnussel@suse.de
- don't enable daemon by default
* Tue Sep  1 2009 coolo@novell.com
- again: use new python macros
* Wed Aug 19 2009 marco@suse.de
- speechd.spec: using py_sitedir instead of python_sitelib
* Tue Aug 18 2009 marco@suse.de
- added build options for espeak support
- --with-pulse --with-espeak
- buildrequirements espeak-devel and pulseaudio-devel
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Sun Jun  7 2009 ro@suse.de
- adapt getline definition to glibc
* Thu Mar 26 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Mon Sep 29 2008 marco@suse.de
- fixed start-script (bug#430563)
* Tue Sep 16 2008 dmueller@suse.de
- move python requires to python subpackage
- fix requires
* Mon Sep 15 2008 dmueller@suse.de
- fix filelist
* Sun Sep 14 2008 marco@suse.de
- added devel section to spec-file
- added suse_python patch to insert start-script
  and to use DESTDIR in the python-bindings makefile
* Thu Sep 11 2008 marco@suse.de
- updated to 0.6.7
* Fri Feb 22 2008 marco@suse.de
- modified the default config to work with espeak by default
* Fri Feb 22 2008 marco@suse.de
- added section in spec file for speechd-python
- modified makefile for python-bindings (added DESTDIR)
* Fri Feb 15 2008 marco@suse.de
- updated to version 0.6.6
- added a suse init-script /etc/init.d/speechd
- added the link /usr/sbin/rcspeechd
* Wed Oct 31 2007 ro@suse.de
- include assert for alsa source
